@@ -4,8 +4,8 @@ VERSION=$2
 TAR=../libmetadata-extractor-java_$VERSION.orig.tar.xz
 DIR=metadata-extractor-$VERSION
 
-git clone --branch 2.6.4 https://code.google.com/p/metadata-extractor $DIR
-rm -Rf $DIR/*.iml $DIR/.git* $DIR/Javadoc/* $DIR/Libraries/*
+git clone --branch $VERSION https://github.com/drewnoakes/metadata-extractor.git $DIR
+rm -Rf $DIR/*.iml $DIR/.git* $DIR/Javadoc/* $DIR/Libraries/* $DIR/.travis.yml
 
 tar -c -J -f $TAR $DIR
 rm -rf $DIR $3
